==> jc-1.4.0.tar.gz: java__5fcup/parse__5faction__5ftable.h <==
// public class java_cup.parse_action_table

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f81ab5ca3a79abce java__5fcup_parse__5faction__5ftable

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_parse__5faction__5ftable_H_
#define _JC_java__5fcup_parse__5faction__5ftable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_parse__5faction__5ftable$sub_refs	_jc_java__5fcup_parse__5faction__5ftable$sub_refs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs	_jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$refs	_jc_java__5fcup_parse__5faction__5ftable$refs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$nonrefs	_jc_java__5fcup_parse__5faction__5ftable$nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$object	_jc_java__5fcup_parse__5faction__5ftable$object;

typedef const struct _jc_java__5fcup_parse__5faction__5ftable$vmethods	_jc_java__5fcup_parse__5faction__5ftable$vmethods;
typedef const struct _jc_java__5fcup_parse__5faction__5ftable$vtable	_jc_java__5fcup_parse__5faction__5ftable$vtable;
typedef const struct _jc_java__5fcup_parse__5faction__5ftable$vtype	_jc_java__5fcup_parse__5faction__5ftable$vtype;

// Constructors
extern void _jc_java__5fcup_parse__5faction__5ftable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);

// Virtual methods
extern void _jc_java__5fcup_parse__5faction__5ftable$method$check__5freductions$02485fe1831969aa(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);
extern jint _jc_java__5fcup_parse__5faction__5ftable$method$num__5fstates$742bbeaf2fa07988(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_parse__5faction__5ftable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_parse__5faction__5ftable$method_info$check__5freductions$02485fe1831969aa;
extern _jc_method _jc_java__5fcup_parse__5faction__5ftable$method_info$num__5fstates$742bbeaf2fa07988;
extern _jc_method _jc_java__5fcup_parse__5faction__5ftable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_parse__5faction__5ftable$vmethods {
	void	(*check__5freductions$02485fe1831969aa)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);
	jint	(*num__5fstates$742bbeaf2fa07988)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *);
};

// Vtable
struct _jc_java__5fcup_parse__5faction__5ftable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_parse__5faction__5ftable$vmethods	java__5fcup_parse__5faction__5ftable;
};

// Vtype
struct _jc_java__5fcup_parse__5faction__5ftable$vtype {
	_jc_type			type;
	_jc_java__5fcup_parse__5faction__5ftable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5ftable$sub_refs {
	_jc_object_array	*under__5fstate;
};

// Reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5ftable$refs {
    _jc_java__5fcup_parse__5faction__5ftable$sub_refs	java__5fcup_parse__5faction__5ftable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs {
	jint	__5fnum__5fstates;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5ftable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs	java__5fcup_parse__5faction__5ftable;
};

// Object instance structure
struct _jc_java__5fcup_parse__5faction__5ftable$object {
	_jc_java__5fcup_parse__5faction__5ftable$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_parse__5faction__5ftable$vtype	*vtype;
	_jc_java__5fcup_parse__5faction__5ftable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_parse__5faction__5ftable$vtype _jc_java__5fcup_parse__5faction__5ftable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_parse__5faction__5ftable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_parse__5faction__5ftable$class_object;

#endif	/* _JC_java__5fcup_parse__5faction__5ftable_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/parse__5faction__5ftable.h <==
// public class java_cup.parse_action_table

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f81ab5ca3a79abce java__5fcup_parse__5faction__5ftable

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_parse__5faction__5ftable_H_
#define _JC_java__5fcup_parse__5faction__5ftable_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_parse__5faction__5ftable$sub_refs	_jc_java__5fcup_parse__5faction__5ftable$sub_refs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs	_jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$refs	_jc_java__5fcup_parse__5faction__5ftable$refs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$nonrefs	_jc_java__5fcup_parse__5faction__5ftable$nonrefs;
typedef struct _jc_java__5fcup_parse__5faction__5ftable$object	_jc_java__5fcup_parse__5faction__5ftable$object;

typedef const struct _jc_java__5fcup_parse__5faction__5ftable$vmethods	_jc_java__5fcup_parse__5faction__5ftable$vmethods;
typedef const struct _jc_java__5fcup_parse__5faction__5ftable$vtable	_jc_java__5fcup_parse__5faction__5ftable$vtable;
typedef const struct _jc_java__5fcup_parse__5faction__5ftable$vtype	_jc_java__5fcup_parse__5faction__5ftable$vtype;

// Constructors
extern void _jc_java__5fcup_parse__5faction__5ftable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java__5fcup_parse__5faction__5ftable$method$check__5freductions$02485fe1831969aa(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_parse__5faction__5ftable$method$num__5fstates$742bbeaf2fa07988(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_parse__5faction__5ftable$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_parse__5faction__5ftable$method_info$check__5freductions$02485fe1831969aa;
extern _jc_method _jc_java__5fcup_parse__5faction__5ftable$method_info$num__5fstates$742bbeaf2fa07988;
extern _jc_method _jc_java__5fcup_parse__5faction__5ftable$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_parse__5faction__5ftable$vmethods {
	void	(*check__5freductions$02485fe1831969aa)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;
	jint	(*num__5fstates$742bbeaf2fa07988)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_parse__5faction__5ftable$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_parse__5faction__5ftable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_parse__5faction__5ftable$vmethods	java__5fcup_parse__5faction__5ftable;
};

// Vtype
struct _jc_java__5fcup_parse__5faction__5ftable$vtype {
	_jc_type			type;
	_jc_java__5fcup_parse__5faction__5ftable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5ftable$sub_refs {
	_jc_object_array	*under__5fstate;
};

// Reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5ftable$refs {
    _jc_java__5fcup_parse__5faction__5ftable$sub_refs	java__5fcup_parse__5faction__5ftable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs {
	jint	__5fnum__5fstates;
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_parse__5faction__5ftable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_parse__5faction__5ftable$sub_nonrefs	java__5fcup_parse__5faction__5ftable;
};

// Object instance structure
struct _jc_java__5fcup_parse__5faction__5ftable$object {
	_jc_java__5fcup_parse__5faction__5ftable$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_parse__5faction__5ftable$vtype	*vtype;
	_jc_java__5fcup_parse__5faction__5ftable$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_parse__5faction__5ftable$vtype _jc_java__5fcup_parse__5faction__5ftable$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_parse__5faction__5ftable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_parse__5faction__5ftable$class_object;

#endif	/* _JC_java__5fcup_parse__5faction__5ftable_H_ */
